7.2-stable review patch.  If anyone has any objections, please let me know.

------------------

From: Farhan Ali <[email protected]>

[ Upstream commit c243e6c470c4695965cc8287767925bc1d9a7867 ]

Introduce a constant for placeholder value and update the kerneldoc for
pci_create_slot() to reference PCI_SLOT_PLACEHOLDER instead of -1
throughout. No functional change.

Suggested-by: Bjorn Helgaas <[email protected]>
Signed-off-by: Farhan Ali <[email protected]>
Signed-off-by: Bjorn Helgaas <[email protected]>
Cc: Madhavan Srinivasan <[email protected]>
Cc: Tyrel Datwyler <[email protected]>
Cc: [email protected]
Link: https://patch.msgid.link/[email protected]
Stable-dep-of: dcc5bec09e23 ("PCI: Allow per function PCI slots to fix slot 
reset on s390")
Signed-off-by: Sasha Levin <[email protected]>
Signed-off-by: Greg Kroah-Hartman <[email protected]>
---
 drivers/pci/hotplug/pnv_php.c     |    2 +-
 drivers/pci/hotplug/rpaphp_slot.c |    2 +-
 drivers/pci/slot.c                |   21 +++++++++++----------
 include/linux/pci.h               |    3 +++
 4 files changed, 16 insertions(+), 12 deletions(-)

--- a/drivers/pci/hotplug/pnv_php.c
+++ b/drivers/pci/hotplug/pnv_php.c
@@ -808,7 +808,7 @@ static struct pnv_php_slot *pnv_php_allo
        if (dn->child && PCI_DN(dn->child))
                php_slot->slot_no = PCI_SLOT(PCI_DN(dn->child)->devfn);
        else
-               php_slot->slot_no = -1;   /* Placeholder slot */
+               php_slot->slot_no = PCI_SLOT_PLACEHOLDER;   /* Placeholder slot 
*/
 
        kref_init(&php_slot->kref);
        php_slot->state                 = PNV_PHP_STATE_INITIALIZED;
--- a/drivers/pci/hotplug/rpaphp_slot.c
+++ b/drivers/pci/hotplug/rpaphp_slot.c
@@ -84,7 +84,7 @@ int rpaphp_register_slot(struct slot *sl
        struct hotplug_slot *php_slot = &slot->hotplug_slot;
        u32 my_index;
        int retval;
-       int slotno = -1;
+       int slotno = PCI_SLOT_PLACEHOLDER;
 
        dbg("%s registering slot:path[%pOF] index[%x], name[%s] pdomain[%x] 
type[%d]\n",
                __func__, slot->dn, slot->index, slot->name,
--- a/include/linux/pci.h
+++ b/include/linux/pci.h
@@ -81,6 +81,9 @@
  */
 #define PCI_SLOT_ALL_DEVICES   0xfe
 
+/* Used to identify a slot as a placeholder */
+#define PCI_SLOT_PLACEHOLDER   0xff
+
 /* pci_slot represents a physical slot */
 struct pci_slot {
        struct pci_bus          *bus;           /* Bus this slot is on */



Reply via email to
--- a/drivers/pci/slot.c
+++ b/drivers/pci/slot.c
@@ -37,7 +37,7 @@ static const struct sysfs_ops pci_slot_s
 
 static ssize_t address_read_file(struct pci_slot *slot, char *buf)
 {
-       if (slot->number == 0xff)
+       if (slot->number == PCI_SLOT_PLACEHOLDER)
                return sysfs_emit(buf, "%04x:%02x\n",
                                  pci_domain_nr(slot->bus),
                                  slot->bus->number);
@@ -210,7 +210,7 @@ static struct pci_slot *get_slot(struct
 /**
  * pci_create_slot - create or increment refcount for physical PCI slot
  * @parent: struct pci_bus of parent bridge
  * @slot_nr: PCI_SLOT(pci_dev->devfn), -1 for placeholder, or
  *     PCI_SLOT_ALL_DEVICES
  * @name: user visible string presented in /sys/bus/pci/slots/<name>
  * @hotplug: set if caller is hotplug driver, NULL otherwise
@@ -236,15 +236,16 @@ static struct pci_slot *get_slot(struct
  * In most cases, @pci_bus, @slot_nr will be sufficient to uniquely identify
  * a slot. There is one notable exception - pSeries (rpaphp), where the
  * @slot_nr cannot be determined until a device is actually inserted into
  * the slot. In this scenario, the caller may pass -1 for @slot_nr.
@slot_nr.
  *
  * The following semantics are imposed when the caller passes @slot_nr ==
  * -1. First, we no longer check for an existing %struct pci_slot, as there
  * may be many slots with @slot_nr of -1.  The other change in semantics is
  * user-visible, which is the 'address' parameter presented in sysfs will
  * consist solely of a dddd:bb tuple, where dddd is the PCI domain of the
  * %struct pci_bus and bb is the bus number. In other words, the devfn of
  * the 'placeholder' slot will not be displayed.
  *
  * Bus-wide slots:
  * For PCIe hotplug, the physical slot encompasses the entire secondary
@@ -267,7 +268,7 @@ struct pci_slot *pci_create_slot(struct
 
        mutex_lock(&pci_slot_mutex);
 
-       if (slot_nr == -1)
+       if (slot_nr == PCI_SLOT_PLACEHOLDER)
                goto placeholder;
 
        /*
@@ -210,7 +210,7 @@ static struct pci_slot *get_slot(struct
  * pci_create_slot - create or increment refcount for physical PCI slot
  * @parent: struct pci_bus of parent bridge
- * @slot_nr: PCI_SLOT(pci_dev->devfn), -1 for placeholder, or
+ * @slot_nr: PCI_SLOT(pci_dev->devfn), PCI_SLOT_PLACEHOLDER for placeholder, or
  *     PCI_SLOT_ALL_DEVICES
  * @name: user visible string presented in /sys/bus/pci/slots/<name>
@@ -236,15 +236,16 @@ static struct pci_slot *get_slot(struct
  * a slot. There is one notable exception - pSeries (rpaphp), where the
  * @slot_nr cannot be determined until a device is actually inserted into
- * the slot. In this scenario, the caller may pass -1 for @slot_nr.
+ * the slot. In this scenario, the caller may pass PCI_SLOT_PLACEHOLDER for 
  *
@@ -236,15 +236,16 @@ static struct pci_slot *get_slot(struct
  *
  * The following semantics are imposed when the caller passes @slot_nr ==
- * -1. First, we no longer check for an existing %struct pci_slot, as there
- * may be many slots with @slot_nr of -1.  The other change in semantics is
- * user-visible, which is the 'address' parameter presented in sysfs will
- * consist solely of a dddd:bb tuple, where dddd is the PCI domain of the
- * %struct pci_bus and bb is the bus number. In other words, the devfn of
- * the 'placeholder' slot will not be displayed.
+ * PCI_SLOT_PLACEHOLDER. First, we no longer check for an existing %struct
+ * pci_slot, as there may be many slots with @slot_nr of
+ * PCI_SLOT_PLACEHOLDER. The other change in semantics is user-visible,
+ * which is the 'address' parameter presented in sysfs will consist solely
+ * of a dddd:bb tuple, where dddd is the PCI domain of the %struct pci_bus
+ * and bb is the bus number. In other words, the devfn of the 'placeholder'
+ * slot will not be displayed.
  *
  * Bus-wide slots: